bayespy.inference.vmp.nodes.dirichlet.DirichletDistribution
===========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. autoclass:: DirichletDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~DirichletDistribution.compute_cgf_from_parents
      ~DirichletDistribution.compute_fixed_moments_and_f
      ~DirichletDistribution.compute_gradient
      ~DirichletDistribution.compute_logpdf
      ~DirichletDistribution.compute_mask_to_parent
      ~DirichletDistribution.compute_message_to_parent
      ~DirichletDistribution.compute_moments_and_cgf
      ~DirichletDistribution.compute_phi_from_parents
      ~DirichletDistribution.plates_from_parent
      ~DirichletDistribution.plates_to_parent
      ~DirichletDistribution.random
   
   

   
   
   